;; This "home-environment" file can be passed to 'guix home reconfigure'
;; to reproduce the content of your profile.  This is "symbolic": it only
;; specifies package names.  To reproduce the exact same profile, you also
;; need to capture the channels being used, as returned by "guix describe".
;; See the "Replicating Guix" section in the manual.

(use-modules (gnu home)
             (gnu packages)
             (gnu packages gnupg)
             (gnu services)
             (guix gexp)
             (guix channels)
             (gnu home services shells)
             (gnu home services dotfiles)
             (gnu home services gnupg)
             (gnu home services shepherd)
             (gnu home services guix))

(home-environment
 ;; Below is the list of packages that will show up in your
 ;; Home profile, under ~/.guix-home/profile.
 (packages (specifications->packages (list "age"
                                           "awscli"
                                           "aws-vault"
                                           "cmake"
                                           "diffstat"
                                           "emacs-no-x"
                                           "gcc-toolchain"
                                           "git"
                                           "git-crypt"
                                           "git-lfs"
                                           "git-semver"
                                           "glibc-locales"
                                           "gnupg"
                                           "go@1.24.2"
                                           "guile"
                                           "guile-algorithms"
                                           "guile-config"
                                           "guile-dsv"
                                           "guile-email"
                                           "guile-fibers"
                                           "guile-filesystem"
                                           "guile-gcrypt"
                                           "guile-gnutls"
                                           "guile-hall"
                                           "guile-ini"
                                           "guile-irregex"
                                           "guile-json"
                                           "guile-lib"
                                           "guile-libyaml"
                                           "guile-lmdb"
                                           "guile-quickcheck"
                                           "guile-readline"
                                           "guile-semver"
                                           "guile-sqlite3"
                                           "guile-srfi-145"
                                           "guile-srfi-158"
                                           "guile-srfi-197"
                                           "guile-srfi-235"
                                           "guile-ssh"
                                           "guile-tap"
                                           "ispell"
                                           "libvterm"
                                           "make"
                                           "nss-certs"
                                           "pass-git-helper"
                                           "password-store"
                                           "pinentry-emacs"
                                           "recutils"
                                           "rsync"
                                           "tree"
                                           "unzip")))

 ;; Below is the list of Home services.  To search for available
 ;; services, run 'guix home search KEYWORD' in a terminal.
 (services
  (list (service home-bash-service-type
                 (home-bash-configuration
                  (guix-defaults? #t)
                  (environment-variables '(("GPG_TTY" . "$(tty)")
                                           ("ALTERNATE_EDITOR" . "")
                                           ("EDITOR" . "emacsclient --tty")
                                           ("VISUAL" . "emacsclient")
                                           ("AWS_VAULT_BACKEND" . "pass")
                                           ("AWS_VAULT_PASS_PREFIX" . "awsvault")))
                  (aliases '())))
        (service home-dotfiles-service-type
                 (home-dotfiles-configuration
                  (directories '("./dotfiles"))
                  (layout 'stow)))
        (service home-gpg-agent-service-type
                 (home-gpg-agent-configuration
                  (default-cache-ttl 7200)
                  (max-cache-ttl 14400)))
        (service home-shepherd-service-type)
        (simple-service 'variant-packages-type
                        home-channels-service-type
                        (list (channel
                               (name 'ray1729)
                               (url "https://forge.1729.org.uk/ray/guix-packages.git")
                               (branch "main")
                               (introduction
                                (make-channel-introduction
                                 "e4656e91d3eec0d4d3a3f752badc4b8cea4b1502"
                                 (openpgp-fingerprint
                                  "2E19 CF82 55B6 A04D 5550  1F2C 043F 786C 4CD6 81B8")))))))))
